@@ -7,6 +7,10 @@ from trytond.exceptions import UserError, UserWarning
 
 class WarningErrorMixin(object):
 
+    @classmethod
+    def _get_error_messages(cls):
+        return cls._error_messages.values()
+
     @classmethod
     def raise_user_error(cls, error, error_args=None,
             error_description='', error_description_args=None,
@@ -38,7 +42,7 @@ class WarningErrorMixin(object):
         if res:
             error = res
 
-        if error_args:
+        if error_args is not None:
             try:
                 error = error % error_args
             except TypeError:
