@@ -15,6 +15,7 @@ from ..transaction import Transaction
 from ..pool import Pool
 from .. import backend
 from ..config import CONFIG
+from ..cache import Cache
 
 __all__ = [
     'Cron',
@@ -175,6 +176,7 @@ class Cron(ModelSQL, ModelView):
     def run(cls, db_name):
         now = datetime.datetime.now()
         with Transaction().start(db_name, 0) as transaction:
+            Cache.clean(db_name)
             transaction.cursor.lock(cls._table)
             crons = cls.search([
                     ('number_calls', '!=', 0),
@@ -207,3 +209,4 @@ class Cron(ModelSQL, ModelView):
                     tb_s = tb_s.decode('utf-8', 'ignore')
                     logger = logging.getLogger('cron')
                     logger.error('Exception:\n%s' % tb_s)
+            Cache.resets(db_name)
