@@ -116,6 +116,7 @@ class Rule(ModelSQL, ModelView):
 
         # Migration from 2.6: replace field, operator and operand by domain
         table.not_null_action('field', action='remove')
+        table.drop_fk('field')
         table.not_null_action('operator', action='remove')
         table.not_null_action('operand', action='remove')
 
@@ -144,7 +145,7 @@ class Rule(ModelSQL, ModelView):
     def _get_context():
         User = Pool().get('res.user')
         user_id = Transaction().user
-        with Transaction().set_user(0, set_context=True):
+        with Transaction().set_context(_check_access=False, _datetime=None):
             user = User(user_id)
         return {
             'user': user,
