@@ -4,9 +4,10 @@ try:
     import simplejson as json
 except ImportError:
     import json
+from sql import Query, Expression
 
-from .field import Field
-from trytond.protocols.jsonrpc import object_hook
+from .field import Field, SQLType
+from ...protocols.jsonrpc import object_hook, JSONEncoder
 
 
 class Dict(Field):
@@ -16,10 +17,10 @@ class Dict(Field):
     def __init__(self, schema_model, string='', help='', required=False,
             readonly=False, domain=None, states=None, select=False,
             on_change=None, on_change_with=None, depends=None,
-            order_field=None, context=None, loading='lazy'):
+            context=None, loading='lazy'):
         super(Dict, self).__init__(string, help, required, readonly, domain,
-            states, select, on_change, on_change_with, depends, order_field,
-            context, loading)
+            states, select, on_change, on_change_with, depends, context,
+            loading)
         self.schema_model = schema_model
 
     def get(self, ids, model, name, values=None):
@@ -29,3 +30,15 @@ class Dict(Field):
                 dicts[value['id']] = json.loads(value[name],
                     object_hook=object_hook)
         return dicts
+
+    @staticmethod
+    def sql_format(value):
+        if isinstance(value, (Query, Expression)):
+            return value
+        if value is None:
+            return None
+        assert isinstance(value, dict)
+        return json.dumps(value, cls=JSONEncoder)
+
+    def sql_type(self):
+        return SQLType('TEXT', 'TEXT')
