@@ -312,8 +312,11 @@ class ModelView(Model):
                     % (field, field))):
                 if type == 'form':
                     element.tag = 'label'
+                    colspan = element.attrib.get('colspan')
                     element.attrib.clear()
                     element.attrib['id'] = 'hidden %s-%s' % (field, i)
+                    if colspan is not None:
+                        element.attrib['colspan'] = colspan
                 elif type == 'tree':
                     parent = element.getparent()
                     parent.remove(element)
