@@ -9,12 +9,14 @@ import sys
 import os
 import signal
 import time
-from trytond.config import CONFIG
 from getpass import getpass
-import hashlib
 import threading
-import string
-import random
+
+from trytond.config import CONFIG
+from trytond import backend
+from trytond.pool import Pool
+from trytond.monitor import monitor
+from .transaction import Transaction
 
 
 class TrytonServer(object):
@@ -27,7 +29,6 @@ class TrytonServer(object):
 
         CONFIG.update_etc(options['configfile'])
         CONFIG.update_cmdline(options)
-        CONFIG.set_timezone()
 
         if CONFIG['logfile']:
             logf = CONFIG['logfile']
@@ -73,9 +74,6 @@ class TrytonServer(object):
 
     def run(self):
         "Run the server and never return"
-        from trytond.backend import Database
-        from trytond.pool import Pool
-        from trytond.monitor import monitor
         update = bool(CONFIG['init'] or CONFIG['update'])
         init = {}
 
@@ -99,33 +97,27 @@ class TrytonServer(object):
 
         for db_name in CONFIG["db_name"]:
             init[db_name] = False
-            database = Database(db_name).connect()
-            cursor = database.cursor()
-
-            try:
+            with Transaction().start(db_name, 0) as transaction:
+                cursor = transaction.cursor
                 if CONFIG['init']:
                     if not cursor.test():
                         self.logger.info("init db")
-                        Database.init(cursor)
+                        backend.get('Database').init(cursor)
                         init[db_name] = True
                     cursor.commit()
                 elif not cursor.test():
                     raise Exception("'%s' is not a Tryton database!" % db_name)
-            finally:
-                cursor.close()
 
         for db_name in CONFIG["db_name"]:
             if update:
-                cursor = Database(db_name).connect().cursor()
-                try:
+                with Transaction().start(db_name, 0) as transaction:
+                    cursor = transaction.cursor
                     if not cursor.test():
                         raise Exception("'%s' is not a Tryton database!"
                             % db_name)
                     cursor.execute('SELECT code FROM ir_lang '
                         'WHERE translatable')
                     lang = [x[0] for x in cursor.fetchall()]
-                finally:
-                    cursor.close()
             else:
                 lang = None
             Pool(db_name).init(update=update, lang=lang)
@@ -160,19 +152,14 @@ class TrytonServer(object):
                             continue
                         break
 
-                database = Database(db_name).connect()
-                cursor = database.cursor()
-                try:
-                    salt = ''.join(random.sample(
-                        string.letters + string.digits, 8))
-                    password += salt
-                    password = hashlib.sha1(password).hexdigest()
-                    cursor.execute('UPDATE res_user '
-                        'SET password = %s, salt = %s '
-                        'WHERE login = \'admin\'', (password, salt))
-                    cursor.commit()
-                finally:
-                    cursor.close()
+                with Transaction().start(db_name, 0) as transaction:
+                    pool = Pool()
+                    User = pool.get('res.user')
+                    admin, = User.search([('login', '=', 'admin')])
+                    User.write([admin], {
+                            'password': password,
+                            })
+                    transaction.cursor.commit()
 
         if update:
             self.logger.info('Update/Init succeed!')
