@@ -1,52 +1,29 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
 import unittest
 import time
 from xmlrpclib import MAXINT
-try:
-    from itertools import combinations
-except ImportError:
-    def combinations(iterable, r):
-        pool = tuple(iterable)
-        n = len(pool)
-        if r > n:
-            return
-        indices = range(r)
-        yield tuple(pool[i] for i in indices)
-        while True:
-            for i in reversed(range(r)):
-                if indices[i] != i + n - r:
-                    break
-            else:
-                return
-            indices[i] += 1
-            for j in range(i + 1, r):
-                indices[j] = indices[j - 1] + 1
-            yield tuple(pool[i] for i in indices)
+from itertools import combinations
+
 from trytond.tests.test_tryton import POOL, DB_NAME, USER, CONTEXT, \
         install_module
-from trytond.test.trigger import TRIGGER_LOGS
+from trytond.tests.trigger import TRIGGER_LOGS
 from trytond.transaction import Transaction
 
 
 class TriggerTestCase(unittest.TestCase):
-    '''
-    Test Trigger
-    '''
+    'Test Trigger'
 
     def setUp(self):
-        install_module('test')
+        install_module('tests')
         self.triggered = POOL.get('test.triggered')
         self.trigger = POOL.get('ir.trigger')
         self.trigger_log = POOL.get('ir.trigger.log')
         self.model = POOL.get('ir.model')
 
     def test0010constraints(self):
-        '''
-        Test constraints
-        '''
+        'Test constraints'
         with Transaction().start(DB_NAME, USER,
                 context=CONTEXT) as transaction:
             model, = self.model.search([
@@ -87,9 +64,7 @@ class TriggerTestCase(unittest.TestCase):
             transaction.cursor.rollback()
 
     def test0020on_create(self):
-        '''
-        Test on_create
-        '''
+        'Test on_create'
         with Transaction().start(DB_NAME, USER,
                 context=CONTEXT) as transaction:
             model, = self.model.search([
@@ -160,9 +135,7 @@ class TriggerTestCase(unittest.TestCase):
             transaction.cursor.rollback()
 
     def test0030on_write(self):
-        '''
-        Test on_write
-        '''
+        'Test on_write'
         with Transaction().start(DB_NAME, USER,
                 context=CONTEXT) as transaction:
             model, = self.model.search([
@@ -273,9 +246,7 @@ class TriggerTestCase(unittest.TestCase):
             transaction.cursor.rollback()
 
     def test0040on_delete(self):
-        '''
-        Test on_delete
-        '''
+        'Test on_delete'
         with Transaction().start(DB_NAME, USER,
                 context=CONTEXT) as transaction:
             model, = self.model.search([
@@ -364,9 +335,7 @@ class TriggerTestCase(unittest.TestCase):
             transaction.cursor.rollback()
 
     def test0050on_time(self):
-        '''
-        Test on_time
-        '''
+        'Test on_time'
         with Transaction().start(DB_NAME, USER,
                 context=CONTEXT) as transaction:
             model, = self.model.search([
@@ -462,7 +431,3 @@ class TriggerTestCase(unittest.TestCase):
 
 def suite():
     return unittest.TestLoader().loadTestsFromTestCase(TriggerTestCase)
-
-if __name__ == '__main__':
-    suite = suite()
-    unittest.TextTestRunner(verbosity=2).run(suite)
